# 正規表現でtextファイルと同じやり方で読み込むのですべて手打ちする．

from .ternary_diagram import TernaryDiagram

__version__      = '2.0.1'
__license__      = 'MIT'
__author__       = 'yu9824'
__copyright__ = 'Copyright © 2021 yu9824'
__author_email__ = 'yu.9824.job@gmail.com'
__user_id__ = 'yu9824'
__app_name__ = 'ternary_diagram'
__url__ = 'http://github.com/yu9824/ternary_diagram/'

__all__ = [
    'TernaryDiagram',
]